@@ -1,6 +1,6 @@
 package CSS::DOM::Parser;
 
-$VERSION = '0.15';
+$VERSION = '0.17';
 
 use strict; use warnings; no warnings qw 'utf8 parenthesis';
 use re 'taint';
@@ -57,7 +57,7 @@ my $function  = qr/$ident\(/;
 # and $dim have to come before $num. 
 $token_re = qr/\G(?:
         ($url)|($uni_range)|($function)|($ident)|($at)|($str)|($invalid)|
-        ($hash)|($percent)|($dim)|($num)|(<!--|-->)|(;)|({)|(})|(\()|(\))
+        ($hash)|($percent)|($dim)|($num)|(<!--|-->)|(;)|(\{)|(})|(\()|(\))
        |(\[)|(])|($space)|(~=)|(\|=)|(,)|(:)|(.)
 )/xs;
 
@@ -578,7 +578,7 @@ sub _decode { my $at; for(''.shift) {
 	) {
 		my $origenc = my $enc = Encode::decode('utf16le', $2);
 		my $dec = eval{Encode::decode($enc, $1, 9)};
-		defined $dec or $dec
+		!defined $dec || $dec !~ /^\@/ and $dec
 			= eval{Encode::decode($enc.='-le', $1, 9)};
 		if(defined $dec) {
 			$dec eq "\@charset \"$origenc\";"
@@ -638,7 +638,7 @@ sub _decode { my $at; for(''.shift) {
 	) {
 		my $origenc = my $enc = Encode::decode('utf32le', $2);
 		my $dec = eval{Encode::decode($enc, $1, 9)};
-		defined $dec or $dec
+		!defined $dec || $dec !~ /^\@/ and $dec
 			= eval{Encode::decode($enc.='-le', $1, 9)};
 		if(defined $dec) {
 			$dec eq "\@charset \"$origenc\";"
@@ -704,7 +704,7 @@ CSS::DOM::Parser - Parser for CSS::DOM
 
 =head1 VERSION
 
-Version 0.15
+Version 0.17
 
 =head1 DESCRIPTION
 
